---
layout: page
title: Appendix II
permalink: /appendix2/
description: "Appendix II: Guidance on Electronic Transactions"
---

## **Appendix II to OMB Circular No. A-130**

**Guidance on Electronic Transactions**

### **Summary**

The Office of Management and Budget (OMB) provides procedures and guidance to implement the Government Paperwork Elimination Act (GPEA) and the Electronic Signatures in Global and National Commerce Act (E-SIGN).

GPEA requires Federal agencies to allow individuals or entities that deal with the agencies the option to submit information or transact with the agency electronically, when practicable, and for agencies to maintain records electronically, when practicable. GPEA specifically states that electronic records and their related electronic signatures are not to be denied legal effect, validity, or enforceability merely because they are in electronic form, and encourages Federal Government use of a range of electronic signature alternatives.

E-SIGN promotes the use of electronic contract formation, signatures, and recordkeeping in private commerce by establishing legal equivalence between: contracts written on paper and contracts in electronic form; pen-and-ink signatures and electronic signatures; and other legally required written documents (termed "records") and the same information in electronic form.

E-SIGN applies broadly to commercial, consumer, and business transactions affecting interstate or foreign commerce, and to transactions regulated by both Federal and State Government.

In support of GPEA and E-SIGN, the General Services Administration and the National Institute of Standards and Technology, in coordination with the Federal CIO Council, maintains guidance on use of Electronic Signatures (E-Signatures) in Federal organization transactions. This guidance expands upon OMB guidance.


### **Background**

This document provides agencies the guidance required under sections 1703 and 1705 of the Government Paperwork Elimination Act (GPEA), Public L. 105-277, Title XVII, signed into law on October 21, 1998, and the Electronic Signatures in Global and National Commerce Act (E-SIGN), Public L. 106-229, signed into law on June 30, 2000. GPEA and E-SIGN are important tools to improve customer service and governmental efficiency through the use of information technology.

As public awareness of electronic communications and Internet usage has increased, demand for on-line interactions with the Federal agencies has also increased. Moving to electronic transactions and electronic signatures can reduce transaction costs for the agency and its partners. Transactions are quicker and information access can be more easily tailored to the specific questions that need to be answered. As a result, data analysis by Federal agencies would be easier. In addition, reengineering the work process associated with transactions may improve efficiency of agency operations.

Public confidence in the security of the government's electronic information processes is essential as agencies make this transition. Electronic commerce, electronic mail, and electronic benefits transfer can require the exchange of sensitive information within government, between the government and private industry or individuals, and among governments. Electronic systems must be able to protect the confidentiality and privacy of information, authenticate the identity of the transacting parties to the degree required by the transaction, guarantee that the information is not altered in an unauthorized way, and provide access when needed. A corresponding policy and management structure must support the infrastructure that delivers these services.

GPEA seeks to "preclude agencies or courts from systematically treating electronic documents and signatures less favorably than their paper counterparts," so that citizens can interact with the Federal Government electronically (S. Rep. 105-335). It required Federal agencies to provide individuals or entities that deal with agencies the option to submit information or transact with the agency electronically, and to maintain records electronically, when practicable. It also addresses the matter of private employers being able to use electronic means to store, and file with Federal agencies, information pertaining to their employees. GPEA states that electronic records and their related electronic signatures are not to be denied legal effect, validity, or enforceability merely because they are in electronic form. It also encourages Federal Government use of a range of electronic signature alternatives. This guidance implements GPEA and supports the continued transition to electronic government.

E-SIGN also eliminates barriers to electronic commerce, while also providing consumers with protections equivalent to those available in the world of paper-based transactions. The Act makes clear that no person is required to use electronic records, signatures, or contracts. E-SIGN requires that a consumer affirmatively consent to the use of electronic notices and records. Prior to consenting, the consumer must receive notice of their rights. Moreover, the consumer must provide the affirmative consent electronically, in a manner that reasonably demonstrates that the consumer can access the electronic records that are the subject of the consent.

E-SIGN applies broadly to Federal and State statutes and regulations governing private sector (including business-to-business and business-to-consumer) activities. It generally covers legal requirements that information be disclosed in private transactions. It also requires that agencies generally permit private parties to retain records electronically. The government may establish appropriate performance standards for the accuracy, integrity, and accessibility of records retained electronically, to ensure compliance with applicable statutes and to guard against fraud.

Agency activities and requirements that involve information, but do not relate to business, commercial, or consumer transactions, are not within the scope of E-SIGN. Instead they are addressed by GPEA. Certain statutes and regulations involve both GPEA and E-SIGN, especially with respect to record retention requirements in agency regulations that relate to business, consumer, and commercial transactions. Additionally, GPEA and E-SIGN guidance builds on the requirements and scope of the Paperwork Reduction Act (PRA) of 1995. All transactions that involve Federal information collections covered under the PRA are also covered under GPEA and E-SIGN. Guidance on implementing the requirements of these Acts is referenced below.

### **Guidance**

Guidance and procedures on implementing the Government Paperwork Elimination Act and E-SIGN are set forth in the documents referenced below:

  a. OMB Memoranda M-00-10, _Procedures and Guidance on Implementing the Government Paperwork Elimination Act,_ April 25, 2000. [https://www.whitehouse.gov/omb/memoranda\_m00-10](https://www.whitehouse.gov/omb/memoranda_m00-10)
  
  b. OMB Memoranda M-00-15, _OMB Guidance on Implementing the Electronic Signatures,_ September 25, 2000. [https://www.whitehouse.gov/omb/memoranda\_m00-15](https://www.whitehouse.gov/omb/memoranda_m00-15)
  
  c. Guidance on Implementing the Electronic Signatures in Global and National Commerce Act (E-SIGN). [https://www.whitehouse.gov/sites/default/files/omb/memoranda/esign-guidance.pdf](https://www.whitehouse.gov/sites/default/files/omb/memoranda/esign-guidance.pdf)
  
  d. Department of Justice, _Legal Considerations in Designing and Implementing Electronic Processes: A Guide for Federal Agencies_, November 2000. [http://www.idmanagement.gov/](http://www.idmanagement.gov/)
  
  e. Federal Chief Information Council, _Use of Electronic Signatures in Federal Organization Transactions_, January 2013. [http://www.idmanagement.gov/](http://www.idmanagement.gov/)

